@@ -18,14 +18,15 @@ sub create_statefile {
   if ($self->opts->snmpwalk && ! $self->opts->hostname) {
     return sprintf "%s/%s_%s%s", $self->statefilesdir(),
         'snmpwalk.file'.md5_hex($self->opts->snmpwalk),
-        $self->opts->mode, lc $extension;
+        $self->clean_path($self->mode), $self->clean_path(lc $extension);
   } elsif ($self->opts->snmpwalk && $self->opts->hostname eq "walkhost") {
     return sprintf "%s/%s_%s%s", $self->statefilesdir(),
         'snmpwalk.file'.md5_hex($self->opts->snmpwalk),
-        $self->mode, lc $extension;
+        $self->clean_path($self->mode), $self->clean_path(lc $extension);
   } else {
     return sprintf "%s/%s_%s%s", $self->statefilesdir(),
-        $self->opts->hostname, $self->mode, lc $extension;
+        $self->opts->hostname,
+        $self->clean_path($self->mode), $self->clean_path(lc $extension);
   }
 }
 
